#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FRAC_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FRAC_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/frac.hpp>

#endif
